`<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
</head>
<?php 
require('../assets/inc/ldapConnect.php');
require('loadDepartment.php');

	$sr=ldap_list($ds,"cn=Modules","(&(objectclass=Module)(modulestatus=0)(|(moduletype=1)(moduletype=10)(moduletype=11)(moduletype=12)(moduletype=17)(moduletype=18)(moduletype=19)(moduletype=3)(moduletype=4)(moduletype=13)(moduletype=14)(moduletype=21)(moduletype=22)))");
    $info = ldap_get_entries($ds, $sr);
	
?>
<body>
<!-- Element to pop up -->
<div style='background-color:#dddddd; border: 4px solid black; padding: 5px; height: 565px; width: 1015px;'>

<div id="wrapper">
        <ul id="tabs">
            <li class="active">Department</li>
            <li>Distribution</li>
			<li>Timing</li>
			<li>Voicemail</li>
			<!-- <li>SpeedDials</li> -->
        </ul>
        <ul id="tab">
		<form id='new_dept'>
		<!-- first tab -->
            <li class="active">
                <h2><span id='deptFormIcon' class=<?php echo $deptClass ?>></span> <span id='deptFormText'><?php if (strlen($deptName) >= 1) echo "'" . $deptName . "' "; echo $deptText ?></span></h2>
				
				
				<!-- #left -->
				<div class="colLeft">
					<div class='field'>
						<label for="cn">Department Name</label>
						<input type='text' id='cn' name='cn' value='<?php echo $deptcn ?>' >
						<span class='information'>PLEASE ENTER DEPARTMENT NAME</span>
					</div>
					<div class='field'>
						<label for="telephonenumber">Telephone Number</label>
						<input type='text' id='telephonenumber' name='telephonenumber' value='<?php echo $telephonenumber ?>' >
						<span class='information'>PLEASE ENTER DEPARTMENT TELEPHONE NUMBER</span>
					</div>
					<div class='field'>
						<label for="description">Description</label>
						<input type='text' id='description' name='description' value='<?php echo $description ?>' >
						<span class='information'>PLEASE ENTER DEPARTMENT DESCRIPTION</span>
					</div>
					
					<div class='field'>
						<label for="outofhoursmode">Out of Hours Mode</label>
						<select id='outofhoursmode' name='outofhoursmode'>
							<option value='0' <?php if ($outofhoursmode == '0' || $outofhoursmode == '') echo 'selected' ?> >Not Used</option>
							<option value='1' <?php if ($outofhoursmode == '1') echo 'selected' ?> >Controlled by TimePlan</option>
							<option value='2' <?php if ($outofhoursmode == '2') echo 'selected' ?> >Out of Hours</option>
							<option value='3' <?php if ($outofhoursmode == '3') echo 'selected' ?> >In Hours</option>
						<select>
						<span class='information'>OUT OF HOURS MODE</span>
					</div>
				</div> 
				<!-- #left -->
				
				
				<!-- #right -->
				<div class="colRight">
					<div class='field'>
						<label for="timeplan">In Hours Time Plan</label>
						<select id='timeplan' name='timeplan'>
						<option></option>
						<?php
						$sr=ldap_list($ds,"cn=timeplans","(objectclass=timeplan)");
						$info = ldap_get_entries($ds, $sr);
						for ($m=0; $m<$info['count']; $m++) {
							$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
							$selected = ($guid == $timeplan) ? 'selected' : '';
							if ($cn === 'EMPTY') continue;
							echo "<option value='$guid' $selected>$cn</option>";	
						}
						?>
						</select>
						<span class='information'>IN HOURS TIME PLAN</span>
					</div>
				
				
					<div class='field'>
						<label for="currenthome">Voicemail Home</label>
						<select id='currenthome' name='currenthome' value='<?php echo $currenthome ?>' >
						<option></option>
						<?php
						$sr=ldap_list($ds,"cn=Modules","(&(objectclass=Module)(modulestatus=0)(|(moduletype=1)(moduletype=10)(moduletype=11)(moduletype=12)(moduletype=17)(moduletype=18)(moduletype=19)))");
						$info = ldap_get_entries($ds, $sr);
						for ($m=0; $m<$info['count']; $m++) {
							$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
							$selected = (($guid == $currenthome) || ($info['count'] == 1)) ? 'selected' : '';
							echo "<option value='$guid' $selected>$cn</option>";	
						}
						?>
						</select>
						<span class='information'>SELECT THE DEPARTMENTS VOICEMAIL HOME</span>
					</div>
					
				<?php if (isset($adminCompany)	&& $adminCompany === '00000000-0000-0000-0000-000000000000') {
					echo "<div class='field'>
						<label for='company'>Company</label>
						<select id='company' name='company' value='$company' >
						<option></option>";
						
						$sr=ldap_list($ds,"cn=companies","(objectclass=company)");
						$info = ldap_get_entries($ds, $sr);
						for ($m=0; $m<$info['count']; $m++) {
							$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
							if ($cn === 'MyCompany') continue;
							$selected = ($guid == $company) ? 'selected' : '';
							echo "<option value='$guid' $selected>$cn</option>";	
						}
				?>
						
						</select>
						<span class='information'>SELECT COMPANY</span>
					</div>
				<?php 
				} 
				?>
					
				</div> 
				<!-- #right -->
			</li>	
			<!-- first tab -->
			
			
			<!-- second tab -->
            <li class="warnings">
				<h2><span id='deptFormIcon' class=<?php echo $deptClass ?>></span> <span id='deptFormText'><?php if (strlen($deptName) >= 1) echo "'" . $deptName . "' - Edit  "; ?>Distribution</span></h2>
				<!-- #left -->
				<div class="colFull">
				
				<div>
					<div class='dist wide'>
						<label for="distributiongroup">Send Inbound Calls</label>
						<b>To:</b> <select id='distributiongroup' name='distributiongroup'>
						<option></option>
						<?php
						$query = ($adminCompany === '00000000-0000-0000-0000-000000000000') ? "cn=Groups" : "cn=Groups, cn=$adminCompany, cn=Companies";
						$sr=ldap_list($ds, $query,"(objectclass=group)");
						$info = ldap_get_entries($ds, $sr);
						
						for ($m=0; $m<$info['count']; $m++) {
							$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
							$selected = ($guid == $distributiongroup) ? 'selected' : '';
							echo "<option value='$guid' $selected>$cn</option>";	
						}
						?>
						</select>
						<b>Ring:</b><select id='distributionmode' name='distributionmode'>
							<option value='0' <?php if ($distributionmode == '0') echo 'selected' ?> ></option>
							<option value='1' <?php if ($distributionmode == '1') echo 'selected' ?> >All</option>
							<option value='2' <?php if ($distributionmode == '2') echo 'selected' ?> >Rotary</option>
							<option value='3' <?php if ($distributionmode == '3') echo 'selected' ?> >Sequential</option>
							<option value='5' <?php if ($distributionmode == '5') echo 'selected' ?> >Vision</option>
						</select>
						<span class='information'>SELECT INITIAL DESTINATION GROUP & RING MODE</span>
					</div>
					
					<div class='dist skip'>
						<label>Skip if Users Busy</label>
						<div class='checkbox'><label for="distributionskiponnotargets"><div class="switch"><input type="checkbox" name='distributionskiponnotargets' id='distributionskiponnotargets' value="1" <?php if ($distributionskiponnotargets == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>NEXT DISTRIBUTION</span>
					</div>
					
					<div class='dist ringfor'>
						<label for="maxringbeforealternatedistributiontime">Or Ring For</label>
						<input type='text' id='maxringbeforealternatedistributiontime' name='maxringbeforealternatedistributiontime' value='<?php echo $maxringbeforealternatedistributiontime ?>' ><b>seconds and then > > ></b>
						<span class='information'>MAX RING TIME BEFORE NEXT DISTRIBUTION</span>
					</div>	
				</div>
				
				<br>
				<?php 
					$disabled = (isset($maxringbeforealternatedistributiontime) && $maxringbeforealternatedistributiontime >0) ? '' : 'disabled';
				?>
				
				<div>
					<div class='dist wide'>
						<label for="alternatedistributiongroup">Send Inbound Calls</label>
						<b>To:</b> <select id='alternatedistributiongroup' name='alternatedistributiongroup' <?php echo $disabled ?>>
						<option></option>
						<?php
						$query = ($adminCompany === '00000000-0000-0000-0000-000000000000') ? "cn=Groups" : "cn=Groups, cn=$adminCompany, cn=Companies";
						$sr=ldap_list($ds, $query,"(objectclass=group)");
						$info = ldap_get_entries($ds, $sr);
						
						for ($m=0; $m<$info['count']; $m++) {
							$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
							$selected = ($guid == $alternatedistributiongroup) ? 'selected' : '';
							echo "<option value='$guid' $selected>$cn</option>";	
						}
						?>
						</select>
						<b>Ring:</b><select id='alternatedistributionmode' name='alternatedistributionmode' <?php echo $disabled ?>>
							<option value='0' <?php if ($alternatedistributionmode == '0') echo 'selected' ?> ></option>
							<option value='1' <?php if ($alternatedistributionmode == '1') echo 'selected' ?> >All</option>
							<option value='2' <?php if ($alternatedistributionmode == '2') echo 'selected' ?> >Rotary</option>
							<option value='3' <?php if ($alternatedistributionmode == '3') echo 'selected' ?> >Sequential</option>
							<option value='5' <?php if ($alternatedistributionmode == '5') echo 'selected' ?> >Vision</option>
						</select>
						<span class='information'>SELECT ALTERNATE DESTINATION GROUP & RING MODE</span>
					</div>
					
					<div class='dist skip'>
						<label>Skip if Users Busy</label>
						<div class='checkbox'><label for="alternatedistributionskiponnotargets"><div class="switch"><input type="checkbox" name='alternatedistributionskiponnotargets' id='alternatedistributionskiponnotargets' value="1" <?php if ($alternatedistributionskiponnotargets == "1") echo "checked"; echo $disabled ?>/><div class="slider"></div></div></label></div>
						<span class='information'>NEXT DISTRIBUTION</span>
					</div>
					
					<div class='dist ringfor'>
						<label for="maxringbeforealternatedistributiontime2">Or Ring For</label>
						<input type='text' id='maxringbeforealternatedistributiontime2' name='maxringbeforealternatedistributiontime2' value='<?php echo $maxringbeforealternatedistributiontime2 . "'" . $disabled ?>><b>seconds and then > > ></b>
						<span class='information'>MAX RING TIME BEFORE NEXT DISTRIBUTION</span>
					</div>	
				</div>	
				
				<br>
				
				<?php 
					$disabled = (isset($maxringbeforealternatedistributiontime) && $maxringbeforealternatedistributiontime >0 && isset($maxringbeforealternatedistributiontime2) && $maxringbeforealternatedistributiontime2 >0) ? '' : 'disabled';
				?>
				
				<div>
					<div class='dist wide'>
						<label for="alternatedistributiongroup2">Send Inbound Calls</label>
						<b>To:</b> <select id='alternatedistributiongroup2' name='alternatedistributiongroup2' <?php echo $disabled ?>>
						<option></option>
						<?php
						$query = ($adminCompany === '00000000-0000-0000-0000-000000000000') ? "cn=Groups" : "cn=Groups, cn=$adminCompany, cn=Companies";
						$sr=ldap_list($ds, $query,"(objectclass=group)");
						$info = ldap_get_entries($ds, $sr);
						
						for ($m=0; $m<$info['count']; $m++) {
							$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
							$selected = ($guid == $alternatedistributiongroup2) ? 'selected' : '';
							echo "<option value='$guid' $selected>$cn</option>";	
						}
						?>
						</select>
						<b>Ring:</b><select id='alternatedistributionmode2' name='alternatedistributionmode2' <?php echo $disabled ?>>
							<option value='0' <?php if ($alternatedistributionmode2 == '0') echo 'selected' ?> ></option>
							<option value='1' <?php if ($alternatedistributionmode2 == '1') echo 'selected' ?> >All</option>
							<option value='2' <?php if ($alternatedistributionmode2 == '2') echo 'selected' ?> >Rotary</option>
							<option value='3' <?php if ($alternatedistributionmode2 == '3') echo 'selected' ?> >Sequential</option>
							<option value='5' <?php if ($alternatedistributionmode2 == '5') echo 'selected' ?> >Vision</option>
						</select>
						<span class='information'>SELECT ALTERNATE 2 DESTINATION GROUP & RING MODE</span>
					</div>
		
				</div>	
				
				
				<div>
					<div class='dist wide'>
						<label for="outofhoursdistributiongroup">When Closed Send Calls</label>
						<b>To:</b> <select id='outofhoursdistributiongroup' name='outofhoursdistributiongroup'>
						<option></option>
						<?php
						$query = ($adminCompany === '00000000-0000-0000-0000-000000000000') ? "cn=Groups" : "cn=Groups, cn=$adminCompany, cn=Companies";
						$sr=ldap_list($ds, $query,"(objectclass=group)");
						$info = ldap_get_entries($ds, $sr);
						
						for ($m=0; $m<$info['count']; $m++) {
							$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
							$selected = ($guid == $outofhoursdistributiongroup) ? 'selected' : '';
							echo "<option value='$guid' $selected>$cn</option>";	
						}
						?>
						</select>
						<b>Ring:</b><select id='outofhoursdistributionmode' name='outofhoursdistributionmode'>
							<option value='0' <?php if ($outofhoursdistributionmode == '0') echo 'selected' ?> ></option>
							<option value='1' <?php if ($outofhoursdistributionmode == '1') echo 'selected' ?> >All</option>
							<option value='2' <?php if ($outofhoursdistributionmode == '2') echo 'selected' ?> >Rotary</option>
							<option value='3' <?php if ($outofhoursdistributionmode == '3') echo 'selected' ?> >Sequential</option>
							<option value='5' <?php if ($outofhoursdistributionmode == '5') echo 'selected' ?> >Vision</option>
						</select>
						<span class='information'>SELECT OUT OF HOURS DESTINATION GROUP & RING MODE</span>
					</div>
					
				</div>	
				
					
				</div> 
				<!-- #right -->
			</li>
			<!-- second tab -->


			<!-- third tab -->
            <li class="warnings">
				<h2><span id='deptFormIcon' class=<?php echo $deptClass ?>></span> <span id='deptFormText'><?php if (strlen($deptName) >= 1) echo "'" . $deptName . "' - Edit  "; ?>Timing</span></h2>
				<!-- #left -->
				<div class="colLeft">
				
					<div class='field telephony'>
						<label for="maxringbeforeannouncementtime">Max Ring Time Before Announcement</label>
						<input type='text' id='maxringbeforeannouncementtime' name='maxringbeforeannouncementtime' value='<?php echo $maxringbeforeannouncementtime ?>' >
						<span class='information'>MAXIMUM RING TIME BEFORE ANNOUNCEMENT</span>
					</div>
					
					<div class='field telephony'>
						<label for="repeatannouncementtime">Repeat Announcement Time</label>
						<input type='text' id='repeatannouncementtime' name='repeatannouncementtime' value='<?php echo $repeatannouncementtime ?>' >
						<span class='information'>REPEAT ANNOUNCEMENT TIME</span>
					</div>					
					
					<div class='field telephony'>
						<label for="maxnumberofactivecallsbeforebusy">Max Number Of Active Calls Before Busy</label>
						<input type='text' id='maxnumberofactivecallsbeforebusy' name='maxnumberofactivecallsbeforebusy' value='<?php echo $maxnumberofactivecallsbeforebusy ?>' >
						<span class='information'>MAXIMUM NUMBER OF ACTIVE CALLS BEFORE BUSY</span>
					</div>
					<br>PLEASE NOTE:<br>Some configuration values of "0" don't mean 0 seconds<br><br>
					Repeat Announcement (0) = 10 seconds<br>
					Wrapup (0) = 6 seconds<br>
					No Answer (0) = 15 seconds<br>
				</div> 
				<!-- #left -->
				
				<!-- #right -->
				<div class="colRight">
					<div class='field telephony'>
						<label for="wrapuptime">Wrap Up Time</label>
						<input type='text' id='wrapuptime' name='wrapuptime' value='<?php echo $wrapuptime ?>' >
						<span class='information'>WRAP UP TIME</span>
					</div>	
					
					<div class='field telephony'>
						<label for="noanswertime">No Answer Time</label>
						<input type='text' id='noanswertime' name='noanswertime' value='<?php echo $noanswertime ?>' >
						<span class='information'>NO ANSWER TIME</span>
					</div>	

					<div class='field telephony'>
						<label for="maxnoanswertimebeforevoicemail">Max No Answer Time Before Voicemail</label>
						<input type='text' id='maxnoanswertimebeforevoicemail' name='maxnoanswertimebeforevoicemail' value='<?php echo $maxnoanswertimebeforevoicemail ?>' >
						<span class='information'>MAXIMUM NO ANSWER TIME BEFORE VOICEMAIL</span>
					</div>	

					<div class='field telephony'>
						<label for="maxnoanswertimebeforevoicemailooh">OOH Max No Answer Time Before Voicemail</label>
						<input type='text' id='maxnoanswertimebeforevoicemailooh' name='maxnoanswertimebeforevoicemailooh' value='<?php echo $maxnoanswertimebeforevoicemailooh ?>' >
						<span class='information'>OUT OF HOURS MAX NO ANSWER TIME BEFORE VOICEMAIL</span>
					</div>						
				
				</div> 
				<!-- #right -->
				
            </li>
			<!-- third tab -->
			
			<!-- fourth tab -->
            <li class="warnings">
				<h2><span id='deptFormIcon' class=<?php echo $deptClass ?>></span> <span id='deptFormText'><?php if (strlen($deptName) >= 1) echo "'" . $deptName . "' - Edit  "; ?>Voicemail</span></h2>
				<!-- #left -->
				<div class="colLeft">
					<div class='field'>
						<label>Voicemail Box Licence</label>
						<div class='checkbox'><label for="messageboxlicense"><div class="switch"><input type="checkbox" name='messageboxlicense' id='messageboxlicense' value="1" <?php if ($messageboxlicense == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>ASSIGN A MESSAGEBOX LICENCE TO THIS DEPARTMENT</span>
					</div>
					
					<div class='field'>
						<label>Enable Voicemail</label>
						<div class='checkbox'><label for="voicemailenabled"><div class="switch"><input type="checkbox" name='voicemailenabled' id='voicemailenabled' value="1" <?php if ($voicemailenabled == "1") echo "checked" ?> /><div class="slider"></div></div></label></div>
						<span class='information'>ENABLE VOICEMAIL ON THIS DEPARTMENT</span>
					</div>		
				
					<div class='field'>
						<label for="voicemailaccesscode">Voicemail Access Code</label>
						<input type='password' id='voicemailaccesscode' name='voicemailaccesscode' value='<?php echo $voicemailaccesscode ?>' >
						<span class='information'>DEPARTMENTS VOICEMAIL ACCESS CODE</span>
					</div>
				</div> 
				<!-- #left -->
				
				<!-- #right -->
				<div class="colRight">
				
				<div class='field'>
					<label for="voicemailmonitor">Add Voicemail Monitor</label>
					<select id='addmonitor' name='addmonitor'>
					<option></option>
					<?php
					$sr=ldap_list($ds,"cn=users","(objectclass=user)", array('cn','telephonenumber','guid'));
					$info = ldap_get_entries($ds, $sr);
					for ($m=0; $m<$info['count']; $m++) {
						$cn = $info[$m]['cn'][0]; 
						$telephonenumber = $info[$m]['telephonenumber'][0]; 
						$guid = $info[$m]['guid'][0];
						echo "<option value='$guid;$cn;$telephonenumber'>$cn ($telephonenumber)</option>";	
					}
					?>
					</select>
					<input class='adduser' type="submit" name="addRow" value="Add Monitor" id="addRow">
					<span class='information'>ADD VOICEMAIL MONITOR</span>
					
				</div>	
				
				<div class="field monitor">
					<label for="voicemailmonitors">Voicemail Monitors</label>
					<?php
					
					$dn = "cn=users";
					$filter="(&(objectclass=*)(|(|(|(|(|(|(|(departmentvoicemail=$deptguid)(departmentvoicemail2=$deptguid)(departmentvoicemail3=$deptguid)(departmentvoicemail4=$deptguid)(departmentvoicemail5=$deptguid)(departmentvoicemail6=$deptguid)(departmentvoicemail7=$deptguid)(departmentvoicemail8=$deptguid)))))))))";
					$justthese = array('cn','telephonenumber','guid');
					$sr=ldap_search($ds, $dn, $filter, $justthese);
					$info = ldap_get_entries($ds, $sr);
					?>
					<div class='monitorcontainer'>
					<table class='monitor' id='vmMonitors' name='vmMonitors'>
						<tbody>
							<?php
							if ($info['count'] <1) {
								echo "<tr class='novm'><td>No Voicemail Monitors Set</td></tr>";
							} else {
								for ($n=0; $n<$info['count']; $n++) {
									$cn = $info[$n]['cn'][0];
									$guid = $info[$n]['guid'][0];
									$telephonenumber = $info[$n]['telephonenumber'][0];
									echo "<tr id='row$n'><td><input id='monitorRow$n' value='$cn ($telephonenumber)' disabled/><input type='hidden' id='monitorValue$n' value='$guid' disabled/></td><td class='delete'><img src='../assets/images/delete.png' class='deleteRow' name='deleteRow' id='deleteRow$n' title='Delete Row'/></td></tr>";
								}
							}
							?>
			        </tbody></table>
					</div>
					<span class="information">DEPARTMENT VOICEMAIL MONITORS</span>
				</div><br>
					
				</div> 
				<!-- #right -->
				
            </li>
				<input type='hidden' id='deptMode' name='deptMode' value='<?php echo $deptMode ?>'>
				<input type='hidden' id='deptName' name='deptName' value='<?php echo $deptName ?>'>
				<input type='hidden' id='guid' name='guid' value='<?php echo $deptguid ?>'>
			</form>
			<!-- fourth tab -->
			
			
			
			<div class='formFooter'>
				<div class='left' id='msg_wrap'>
					<span id='msg'></span>
				</div>
			
				<div class='right'>

					<input type='button' class='close' id ='close' value='Close'/>
					<input type='button' class='save' id='save' value='Save'/>
				</div>
			</div>

		</ul>
    </div>
	
</div>	
</body>
</html>
